# This is an auto-generated file, please do not modify

QUERIES = {'byauthorsorted': '\n  query ByAuthorSorted(\n    $author: String\n    $updatedAt: ModelStringKeyConditionInput\n    $sortDirection: ModelSortDirection\n    $filter: ModelAllRunbooksFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    byAuthorSorted(\n      author: $author\n      updatedAt: $updatedAt\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'byinvsorted': '\n  query ByInvSorted(\n    $investigationId: ID\n    $updatedAt: ModelStringKeyConditionInput\n    $sortDirection: ModelSortDirection\n    $filter: ModelInvestigationEventFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    byInvSorted(\n      investigationId: $investigationId\n      updatedAt: $updatedAt\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        author\n        content\n        type\n        links\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'epicbyibid': '\n  query EpicByIbid(\n    $investigationId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelepicAutoCompleteFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    epicByIBID(\n      investigationId: $investigationId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        author\n        cliCommand\n        command\n        createdAt\n        updatedAt\n        investigationId\n        times\n      }\n      nextToken\n    }\n  }\n',
 'getallrunbooks': '\n  query GetAllRunbooks($id: ID!) {\n    getAllRunbooks(id: $id) {\n      id\n      name\n      description\n      content\n      author\n      commands\n      createdAt\n      updatedAt\n      RunBookConnectors\n      type\n      longSave\n      rbVars\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      connectorForms {\n        nextToken\n      }\n    }\n  }\n',
 'getallworkflows': '\n  query GetAllWorkflows($id: ID!) {\n    getAllWorkflows(id: $id) {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      author\n      longSave\n      rbVars\n    }\n  }\n',
 'getchannel': '\n  query GetChannel($id: ID!) {\n    getChannel(id: $id) {\n      id\n      messages {\n        nextToken\n      }\n      associated {\n        nextToken\n      }\n      name\n      title\n      members\n      membersState\n      createdAt\n      updatedAt\n      memberLocation\n    }\n  }\n',
 'getchannellink': '\n  query GetChannelLink($id: ID!) {\n    getChannelLink(id: $id) {\n      id\n      contactId\n      channel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      chatId\n      unread\n      createdAt\n      updatedAt\n      user {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'getchat': '\n  query GetChat($id: ID!) {\n    getChat(id: $id) {\n      id\n      from\n      content\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getcheatsheet': '\n  query GetCheatSheet($id: ID!) {\n    getCheatSheet(id: $id) {\n      id\n      createdAt\n      updatedAt\n      title\n      author\n      content\n      type\n    }\n  }\n',
 'getchecklist': '\n  query GetCheckList($id: ID!) {\n    getCheckList(id: $id) {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      content\n      author\n      CheckListLink {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n    }\n  }\n',
 'getchecklistinvlink': '\n  query GetCheckListInvLink($id: ID!) {\n    getCheckListInvLink(id: $id) {\n      id\n      createdAt\n      updatedAt\n      investigationID\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      owner\n    }\n  }\n',
 'getchecklistitem': '\n  query GetCheckListItem($id: ID!) {\n    getCheckListItem(id: $id) {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      type\n      connection\n      MMNodeConnection\n      investigationID\n      assignee\n      associatedPlaybooks\n      associatedCommands\n      CheckListLink {\n        nextToken\n      }\n    }\n  }\n',
 'getclick': '\n  query GetClick($id: ID!) {\n    getClick(id: $id) {\n      id\n      count\n      type\n      featureName\n      createdAt\n      updatedAt\n      readAt\n    }\n  }\n',
 'getclicllink': '\n  query GetCliclLink($id: ID!) {\n    getCLICLLink(id: $id) {\n      id\n      createdAt\n      updatedAt\n      CheckListItemID\n      lane\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      CheckListItem {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n    }\n  }\n',
 'getcommands': '\n  query GetCommands($id: ID!) {\n    getCommands(id: $id) {\n      id\n      from\n      mode\n      command\n      output\n      state\n      returnCode\n      investigationId\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getcomment': '\n  query GetComment($id: ID!) {\n    getComment(id: $id) {\n      id\n      parent\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getconferenceconfig': '\n  query GetConferenceConfig($id: ID!) {\n    getConferenceConfig(id: $id) {\n      id\n      url\n      userName\n      password\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getconnectorform': '\n  query GetConnectorForm($id: ID!) {\n    getConnectorForm(id: $id) {\n      id\n      createdAt\n      updatedAt\n      name\n      owner\n      connectorID\n      connector {\n        id\n        createdAt\n        updatedAt\n        category\n        name\n        owner\n        description\n        detaileddescription\n        iconPath\n        version\n        md5\n        source\n        configuration\n        commands\n        commandsType\n        script\n        scriptType\n        scriptPath\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      configData\n      commandData\n      nodeData\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      runbooks {\n        nextToken\n      }\n    }\n  }\n',
 'getconnectors': '\n  query GetConnectors($id: ID!) {\n    getConnectors(id: $id) {\n      id\n      createdAt\n      updatedAt\n      category\n      name\n      owner\n      description\n      detaileddescription\n      iconPath\n      version\n      md5\n      source\n      configuration\n      commands\n      commandsType\n      script\n      scriptType\n      scriptPath\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'getdashboardconfig': '\n  query GetDashboardConfig($id: ID!) {\n    getDashboardConfig(id: $id) {\n      id\n      url\n      labels {\n        nextToken\n      }\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getdashboardconfiglabellink': '\n  query GetDashboardConfigLabelLink($id: ID!) {\n    getDashboardConfigLabelLink(id: $id) {\n      id\n      dashboardConfigID\n      labelID\n      dashboardConfig {\n        id\n        url\n        author\n        createdAt\n        updatedAt\n      }\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getecubesandboxexecution': '\n  query GetEcubeSandboxExecution($id: ID!) {\n    getEcubeSandboxExecution(id: $id) {\n      id\n      owner\n      output\n      outputType\n      returnCode\n      status\n      createdAt\n      updatedAt\n      E3One\n      E3Two\n      E3Three\n    }\n  }\n',
 'getepicautocomplete': '\n  query GetEpicAutoComplete($id: ID!) {\n    getEpicAutoComplete(id: $id) {\n      id\n      author\n      cliCommand\n      command\n      createdAt\n      updatedAt\n      investigationId\n      times\n    }\n  }\n',
 'getepiclicommand': '\n  query GetEpicliCommand($id: ID!) {\n    getEPICLICommand(id: $id) {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'getexecutedrunbooks': '\n  query GetExecutedRunbooks($id: ID!) {\n    getExecutedRunbooks(id: $id) {\n      id\n      createdAt\n      updatedAt\n      runbookID\n      investigationId\n      output\n      outputType\n      title\n      state\n      author\n      rbVars\n      callbackUrl\n      callbackData\n      source\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'getexecutedworkflowstate': '\n  query GetExecutedWorkflowState($id: ID!) {\n    getExecutedWorkflowState(id: $id) {\n      id\n      createdAt\n      updatedAt\n      name\n      state\n      output\n      type\n      allworkflowID\n      investigationID\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getgroupmember': '\n  query GetGroupMember($id: ID!) {\n    getGroupMember(id: $id) {\n      id\n      hostId\n      groupId\n      host {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        host\n        port\n        vars\n      }\n      group {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        name\n        groups\n        port\n        vars\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getguardrail': '\n  query GetGuardRail($id: ID!) {\n    getGuardRail(id: $id) {\n      id\n      timeOut\n      message\n      labels {\n        nextToken\n      }\n      author\n      active\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getguardraillabellink': '\n  query GetGuardRailLabelLink($id: ID!) {\n    getGuardRailLabelLink(id: $id) {\n      id\n      guardRailID\n      labelID\n      guardRail {\n        id\n        timeOut\n        message\n        author\n        active\n        createdAt\n        updatedAt\n      }\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'gethint': '\n  query GetHint($id: ID!) {\n    getHint(id: $id) {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      type\n      connection\n      pastInvestigationID\n      title\n      importance\n      starrted\n      applied\n      url\n      why\n    }\n  }\n',
 'getinventory': '\n  query GetInventory($id: ID!) {\n    getInventory(id: $id) {\n      id\n      createdAt\n      updatedAt\n      author\n      name\n      all {\n        nextToken\n      }\n      groups {\n        nextToken\n      }\n      vars\n    }\n  }\n',
 'getinventorygroup': '\n  query GetInventoryGroup($id: ID!) {\n    getInventoryGroup(id: $id) {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      name\n      hosts {\n        nextToken\n      }\n      groups\n      port\n      vars\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'getinventoryhost': '\n  query GetInventoryHost($id: ID!) {\n    getInventoryHost(id: $id) {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      host\n      port\n      vars\n      groups {\n        nextToken\n      }\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'getinvestigation': '\n  query GetInvestigation($id: ID!) {\n    getInvestigation(id: $id) {\n      id\n      title\n      from\n      createdAt\n      currentState\n      HumanID\n      currentStateID\n      severity\n      priority\n      location\n      labels {\n        nextToken\n      }\n      channelId\n      investigationChannel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      updatedAt\n      resolvedTime\n      resolvedComment\n      Symptoms\n      MMNodeLinks {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n      meetingType\n      meetingId\n    }\n  }\n',
 'getinvestigationevent': '\n  query GetInvestigationEvent($id: ID!) {\n    getInvestigationEvent(id: $id) {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getinvestigationguestuserlink': '\n  query GetInvestigationGuestUserLink($id: ID!) {\n    getInvestigationGuestUserLink(id: $id) {\n      id\n      userName\n      createdAt\n      updatedAt\n      investigationID\n      channelID\n    }\n  }\n',
 'getlabel': '\n  query GetLabel($id: ID!) {\n    getLabel(id: $id) {\n      id\n      name\n      color\n      type\n      investigations {\n        nextToken\n      }\n      userSettings {\n        nextToken\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getlabellink': '\n  query GetLabelLink($id: ID!) {\n    getLabelLink(id: $id) {\n      id\n      investigationID\n      labelID\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getleadboard': '\n  query GetLeadBoard($id: ID!) {\n    getLeadBoard(id: $id) {\n      id\n      investigationId\n      content\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getleadboardnode': '\n  query GetLeadBoardNode($id: ID!) {\n    getLeadBoardNode(id: $id) {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      notes\n      associatedPlaybooks\n      associatedCommands\n      InvestLinks {\n        nextToken\n      }\n    }\n  }\n',
 'getmessage': '\n  query GetMessage($id: ID!) {\n    getMessage(id: $id) {\n      id\n      authorId\n      content\n      type\n      channel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      messageChannelId\n      createdAt\n      updatedAt\n      author {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'getmmnodelink': '\n  query GetMmNodeLink($id: ID!) {\n    getMMNodeLink(id: $id) {\n      id\n      createdAt\n      updatedAt\n      assigned\n      state\n      content\n      author\n      investigationID\n      connectionToTask\n      LBNID\n      LeadBoardNodeId {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      investigationId {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getnotification': '\n  query GetNotification($id: ID!) {\n    getNotification(id: $id) {\n      id\n      userName\n      content\n      containerType\n      containerId\n      investigationId\n      isViewed\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getpin': '\n  query GetPin($id: ID!) {\n    getPin(id: $id) {\n      id\n      imageId\n      content\n      createdAt\n      updatedAt\n      author\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getprivatekey': '\n  query GetPrivateKey($id: ID!) {\n    getPrivateKey(id: $id) {\n      id\n      sshKey\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getremotecontrol': '\n  query GetRemoteControl($id: ID!) {\n    getRemoteControl(id: $id) {\n      id\n      from\n      to\n      command\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getreportsummaryeditor': '\n  query GetReportSummaryEditor($id: ID!) {\n    getReportSummaryEditor(id: $id) {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'getrunbookconnectorformlink': '\n  query GetRunbookConnectorFormLink($id: ID!) {\n    getRunbookConnectorFormLink(id: $id) {\n      id\n      connectorFormId\n      runbookId\n      connectorForm {\n        id\n        createdAt\n        updatedAt\n        name\n        owner\n        connectorID\n        configData\n        commandData\n        nodeData\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      createdAt\n      updatedAt\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'getschedpbs': '\n  query GetSchedPBs($id: ID!) {\n    getSchedPBs(id: $id) {\n      id\n      pbId\n      frequency\n      pbName\n      rbVars\n      scheduled\n      createdAt\n      updatedAt\n      author\n    }\n  }\n',
 'getslackchannelinfo': '\n  query GetSlackChannelInfo($id: ID!) {\n    getSlackChannelInfo(id: $id) {\n      id\n      owner\n      slackChannelId\n      slackAppId\n      slackTeamId\n      createdAt\n      updatedAt\n      slackTeam {\n        id\n        owner\n        teamId\n        teamName\n        slackAppId\n        botId\n        botToken\n        botScope\n        enterprise\n        createdAt\n        updatedAt\n      }\n      usersEnabled {\n        nextToken\n      }\n    }\n  }\n',
 'getslackenabledchannelsuserlink': '\n  query GetSlackEnabledChannelsUserLink($id: ID!) {\n    getSlackEnabledChannelsUserLink(id: $id) {\n      id\n      owner\n      slackUserId\n      slackChannelId\n      createdAt\n      updatedAt\n      slackUser {\n        id\n        userAppSyncId\n        userName\n        userId\n        userScope\n        userToken\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      slackChannel {\n        id\n        owner\n        slackChannelId\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n    }\n  }\n',
 'getslackteaminfo': '\n  query GetSlackTeamInfo($id: ID!) {\n    getSlackTeamInfo(id: $id) {\n      id\n      owner\n      teamId\n      teamName\n      slackAppId\n      botId\n      botToken\n      botScope\n      enterprise\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getslackuserinfo': '\n  query GetSlackUserInfo($id: ID!) {\n    getSlackUserInfo(id: $id) {\n      id\n      userAppSyncId\n      userName\n      userId\n      userScope\n      userToken\n      slackAppId\n      slackTeamId\n      createdAt\n      updatedAt\n      userGqlInfo {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n      slackTeam {\n        id\n        owner\n        teamId\n        teamName\n        slackAppId\n        botId\n        botToken\n        botScope\n        enterprise\n        createdAt\n        updatedAt\n      }\n      channelsEnabled {\n        nextToken\n      }\n    }\n  }\n',
 'getsshtabs': '\n  query GetSshTabs($id: ID!) {\n    getSshTabs(id: $id) {\n      id\n      investigationId\n      host\n      author\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'getstash': '\n  query GetStash($id: ID!) {\n    getStash(id: $id) {\n      id\n      Key\n      Value\n      createdAt\n      updatedAt\n      author\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'getstashbykey': '\n  query GetStashByKey(\n    $Key: String\n    $sortDirection: ModelSortDirection\n    $filter: ModelStashFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    GetStashByKey(\n      Key: $Key\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        Key\n        Value\n        createdAt\n        updatedAt\n        author\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'getstate': '\n  query GetState($id: ID!) {\n    getState(id: $id) {\n      id\n      name\n      createdAt\n      updatedAt\n      author\n      lastState\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getsummaryinvestigation': '\n  query GetSummaryInvestigation($id: ID!) {\n    getSummaryInvestigation(id: $id) {\n      id\n      createdAt\n      updatedAt\n      resolvedTime\n      OriginalID\n      title\n      HumanID\n      Commands\n      InvestigationEvents\n      CompleteInvestigationEvents\n      Participants\n      Comments\n      Pins\n      AvailableRunbooks\n      UsedRunbooks\n      Hints\n      Symptoms\n      owner\n    }\n  }\n',
 'gettenantcustomer': '\n  query GetTenantCustomer($id: ID!) {\n    getTenantCustomer(id: $id) {\n      label\n      impactLabels\n      createdAt\n      updatedAt\n      customerName\n      email\n      phoneno\n      SLAType\n      city\n      state\n      contry\n      zipcode\n    }\n  }\n',
 'gettranscriptionrecords': '\n  query GetTranscriptionRecords($id: ID!) {\n    getTranscriptionRecords(id: $id) {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      spokenBy\n      content\n    }\n  }\n',
 'getusedtogenhintalready': '\n  query GetUsedToGenHintAlready($id: ID!) {\n    getUsedToGenHintAlready(id: $id) {\n      id\n      createdAt\n      updatedAt\n      investigationId\n      commands\n      text\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'getuser': '\n  query GetUser($id: ID!) {\n    getUser(id: $id) {\n      id\n      username\n      email\n      firstname\n      lastname\n      avatar\n      mood\n      name\n      role\n      status\n      timezone\n      phone\n      address\n      location\n      chatList {\n        nextToken\n      }\n      messages {\n        nextToken\n      }\n      createdAt\n      updatedAt\n      owner\n    }\n  }\n',
 'getuseractivity': '\n  query GetUserActivity($id: ID!) {\n    getUserActivity(id: $id) {\n      id\n      userID\n      status\n      investigationID\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      user {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'getusersetting': '\n  query GetUserSetting($id: ID!) {\n    getUserSetting(id: $id) {\n      id\n      userId\n      owner\n      createdAt\n      updatedAt\n      labels {\n        nextToken\n      }\n      value\n      url\n      name\n      type\n      showWelcomeNext\n      showWelcomeSkip\n      showWelcomeRemind\n      welcomeData\n    }\n  }\n',
 'getusersettinglabellink': '\n  query GetUserSettingLabelLink($id: ID!) {\n    getUserSettingLabelLink(id: $id) {\n      id\n      userSettingId\n      userSetting {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      labelID\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      type\n      createdAt\n      updatedAt\n    }\n  }\n',
 'iblinkbyuser': '\n  query IbLinkByUser(\n    $userName: String\n    $sortDirection: ModelSortDirection\n    $filter: ModelInvestigationGuestUserLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    IbLinkByUser(\n      userName: $userName\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userName\n        createdAt\n        updatedAt\n        investigationID\n        channelID\n      }\n      nextToken\n    }\n  }\n',
 'listallrunbookss': '\n  query ListAllRunbookss(\n    $filter: ModelAllRunbooksFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listAllRunbookss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'listallworkflowss': '\n  query ListAllWorkflowss(\n    $filter: ModelAllWorkflowsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listAllWorkflowss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        author\n        longSave\n        rbVars\n      }\n      nextToken\n    }\n  }\n',
 'listchannellinks': '\n  query ListChannelLinks(\n    $filter: ModelChannelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listChannelLinks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        contactId\n        chatId\n        unread\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listchannels': '\n  query ListChannels(\n    $filter: ModelChannelFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listChannels(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      nextToken\n    }\n  }\n',
 'listchats': '\n  query ListChats(\n    $filter: ModelChatFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listChats(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        from\n        content\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listcheatsheets': '\n  query ListCheatSheets(\n    $filter: ModelCheatSheetFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCheatSheets(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        title\n        author\n        content\n        type\n      }\n      nextToken\n    }\n  }\n',
 'listchecklistinvlinks': '\n  query ListCheckListInvLinks(\n    $filter: ModelCheckListInvLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCheckListInvLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        investigationID\n        CheckListID\n        owner\n      }\n      nextToken\n    }\n  }\n',
 'listchecklistitems': '\n  query ListCheckListItems(\n    $filter: ModelCheckListItemFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCheckListItems(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n      nextToken\n    }\n  }\n',
 'listchecklists': '\n  query ListCheckLists(\n    $filter: ModelCheckListFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCheckLists(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      nextToken\n    }\n  }\n',
 'listclicks': '\n  query ListClicks(\n    $filter: ModelClickFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listClicks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        count\n        type\n        featureName\n        createdAt\n        updatedAt\n        readAt\n      }\n      nextToken\n    }\n  }\n',
 'listclicllinks': '\n  query ListCliclLinks(\n    $filter: ModelCLICLLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCLICLLinks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        CheckListItemID\n        lane\n        CheckListID\n      }\n      nextToken\n    }\n  }\n',
 'listcommandss': '\n  query ListCommandss(\n    $filter: ModelCommandsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listCommandss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        from\n        mode\n        command\n        output\n        state\n        returnCode\n        investigationId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listcomments': '\n  query ListComments(\n    $filter: ModelCommentFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listComments(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        parent\n        createdAt\n        updatedAt\n        author\n        content\n        type\n        links\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'listconferenceconfigs': '\n  query ListConferenceConfigs(\n    $filter: ModelConferenceConfigFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listConferenceConfigs(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        url\n        userName\n        password\n        author\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listconnectorforms': '\n  query ListConnectorForms(\n    $filter: ModelConnectorFormFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listConnectorForms(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        owner\n        connectorID\n        configData\n        commandData\n        nodeData\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'listconnectorss': '\n  query ListConnectorss(\n    $filter: ModelConnectorsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listConnectorss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        category\n        name\n        owner\n        description\n        detaileddescription\n        iconPath\n        version\n        md5\n        source\n        configuration\n        commands\n        commandsType\n        script\n        scriptType\n        scriptPath\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'listdashboardconfiglabellinks': '\n  query ListDashboardConfigLabelLinks(\n    $filter: ModelDashboardConfigLabelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listDashboardConfigLabelLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        dashboardConfigID\n        labelID\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listdashboardconfigs': '\n  query ListDashboardConfigs(\n    $filter: ModelDashboardConfigFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listDashboardConfigs(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        url\n        author\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listecubesandboxexecutions': '\n  query ListEcubeSandboxExecutions(\n    $filter: ModelEcubeSandboxExecutionFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listEcubeSandboxExecutions(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        owner\n        output\n        outputType\n        returnCode\n        status\n        createdAt\n        updatedAt\n        E3One\n        E3Two\n        E3Three\n      }\n      nextToken\n    }\n  }\n',
 'listepicautocompletes': '\n  query ListEpicAutoCompletes(\n    $filter: ModelepicAutoCompleteFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listEpicAutoCompletes(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        author\n        cliCommand\n        command\n        createdAt\n        updatedAt\n        investigationId\n        times\n      }\n      nextToken\n    }\n  }\n',
 'listepiclicommands': '\n  query ListEpicliCommands(\n    $filter: ModelEPICLICommandFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listEPICLICommands(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        author\n        content\n        type\n      }\n      nextToken\n    }\n  }\n',
 'listexecutedrunbookss': '\n  query ListExecutedRunbookss(\n    $filter: ModelExecutedRunbooksFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listExecutedRunbookss(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        runbookID\n        investigationId\n        output\n        outputType\n        title\n        state\n        author\n        rbVars\n        callbackUrl\n        callbackData\n        source\n      }\n      nextToken\n    }\n  }\n',
 'listexecutedworkflowstates': '\n  query ListExecutedWorkflowStates(\n    $filter: ModelExecutedWorkflowStateFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listExecutedWorkflowStates(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        state\n        output\n        type\n        allworkflowID\n        investigationID\n      }\n      nextToken\n    }\n  }\n',
 'listgroupmembers': '\n  query ListGroupMembers(\n    $filter: ModelGroupMemberFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listGroupMembers(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        hostId\n        groupId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listguardraillabellinks': '\n  query ListGuardRailLabelLinks(\n    $filter: ModelGuardRailLabelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listGuardRailLabelLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        guardRailID\n        labelID\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listguardrails': '\n  query ListGuardRails(\n    $filter: ModelGuardRailFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listGuardRails(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        timeOut\n        message\n        author\n        active\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listhints': '\n  query ListHints(\n    $filter: ModelHintFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listHints(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        type\n        connection\n        pastInvestigationID\n        title\n        importance\n        starrted\n        applied\n        url\n        why\n      }\n      nextToken\n    }\n  }\n',
 'listinventorygroups': '\n  query ListInventoryGroups(\n    $filter: ModelInventoryGroupFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInventoryGroups(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        name\n        groups\n        port\n        vars\n      }\n      nextToken\n    }\n  }\n',
 'listinventoryhosts': '\n  query ListInventoryHosts(\n    $filter: ModelInventoryHostFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInventoryHosts(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        host\n        port\n        vars\n      }\n      nextToken\n    }\n  }\n',
 'listinventorys': '\n  query ListInventorys(\n    $filter: ModelInventoryFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInventorys(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n      nextToken\n    }\n  }\n',
 'listinvestigationevents': '\n  query ListInvestigationEvents(\n    $filter: ModelInvestigationEventFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInvestigationEvents(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        author\n        content\n        type\n        links\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'listinvestigationguestuserlinks': '\n  query ListInvestigationGuestUserLinks(\n    $filter: ModelInvestigationGuestUserLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInvestigationGuestUserLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userName\n        createdAt\n        updatedAt\n        investigationID\n        channelID\n      }\n      nextToken\n    }\n  }\n',
 'listinvestigations': '\n  query ListInvestigations(\n    $filter: ModelInvestigationFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listInvestigations(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      nextToken\n    }\n  }\n',
 'listlabellinks': '\n  query ListLabelLinks(\n    $filter: ModelLabelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listLabelLinks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        investigationID\n        labelID\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listlabels': '\n  query ListLabels(\n    $filter: ModelLabelFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listLabels(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listleadboardnodes': '\n  query ListLeadBoardNodes(\n    $filter: ModelLeadBoardNodeFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listLeadBoardNodes(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      nextToken\n    }\n  }\n',
 'listleadboards': '\n  query ListLeadBoards(\n    $filter: ModelLeadBoardFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listLeadBoards(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        investigationId\n        content\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listmessages': '\n  query ListMessages(\n    $filter: ModelMessageFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listMessages(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        authorId\n        content\n        type\n        messageChannelId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listmmnodelinks': '\n  query ListMmNodeLinks(\n    $filter: ModelMMNodeLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listMMNodeLinks(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        createdAt\n        updatedAt\n        assigned\n        state\n        content\n        author\n        investigationID\n        connectionToTask\n        LBNID\n      }\n      nextToken\n    }\n  }\n',
 'listnotifications': '\n  query ListNotifications(\n    $filter: ModelNotificationFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listNotifications(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        userName\n        content\n        containerType\n        containerId\n        investigationId\n        isViewed\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listpins': '\n  query ListPins(\n    $filter: ModelPinFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listPins(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        imageId\n        content\n        createdAt\n        updatedAt\n        author\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'listprivatekeys': '\n  query ListPrivateKeys(\n    $filter: ModelPrivateKeyFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listPrivateKeys(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        sshKey\n        userName\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listremotecontrols': '\n  query ListRemoteControls(\n    $filter: ModelremoteControlFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listRemoteControls(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        from\n        to\n        command\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listreportsummaryeditors': '\n  query ListReportSummaryEditors(\n    $filter: ModelReportSummaryEditorFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listReportSummaryEditors(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        author\n        content\n        type\n      }\n      nextToken\n    }\n  }\n',
 'listrunbookconnectorformlinks': '\n  query ListRunbookConnectorFormLinks(\n    $filter: ModelRunbookConnectorFormLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listRunbookConnectorFormLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        connectorFormId\n        runbookId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listschedpbss': '\n  query ListSchedPBss(\n    $filter: ModelSchedPBsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSchedPBss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        pbId\n        frequency\n        pbName\n        rbVars\n        scheduled\n        createdAt\n        updatedAt\n        author\n      }\n      nextToken\n    }\n  }\n',
 'listslackchannelinfos': '\n  query ListSlackChannelInfos(\n    $filter: ModelSlackChannelInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSlackChannelInfos(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        owner\n        slackChannelId\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listslackenabledchannelsuserlinks': '\n  query ListSlackEnabledChannelsUserLinks(\n    $filter: ModelSlackEnabledChannelsUserLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSlackEnabledChannelsUserLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        owner\n        slackUserId\n        slackChannelId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listslackteaminfos': '\n  query ListSlackTeamInfos(\n    $filter: ModelSlackTeamInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSlackTeamInfos(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        owner\n        teamId\n        teamName\n        slackAppId\n        botId\n        botToken\n        botScope\n        enterprise\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listslackuserinfos': '\n  query ListSlackUserInfos(\n    $filter: ModelSlackUserInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSlackUserInfos(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        userAppSyncId\n        userName\n        userId\n        userScope\n        userToken\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listsshtabss': '\n  query ListSshTabss(\n    $filter: ModelSshTabsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSshTabss(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        investigationId\n        host\n        author\n        userName\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'liststashs': '\n  query ListStashs(\n    $filter: ModelStashFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listStashs(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        Key\n        Value\n        createdAt\n        updatedAt\n        author\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n    }\n  }\n',
 'liststates': '\n  query ListStates(\n    $filter: ModelStateFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listStates(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        name\n        createdAt\n        updatedAt\n        author\n        lastState\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'listsummaryinvestigations': '\n  query ListSummaryInvestigations(\n    $filter: ModelSummaryInvestigationFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listSummaryInvestigations(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        resolvedTime\n        OriginalID\n        title\n        HumanID\n        Commands\n        InvestigationEvents\n        CompleteInvestigationEvents\n        Participants\n        Comments\n        Pins\n        AvailableRunbooks\n        UsedRunbooks\n        Hints\n        Symptoms\n        owner\n      }\n      nextToken\n    }\n  }\n',
 'listtenantcustomers': '\n  query ListTenantCustomers(\n    $filter: ModelTenantCustomerFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listTenantCustomers(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        label\n        impactLabels\n        createdAt\n        updatedAt\n        customerName\n        email\n        phoneno\n        SLAType\n        city\n        state\n        contry\n        zipcode\n      }\n      nextToken\n    }\n  }\n',
 'listtranscriptionrecordss': '\n  query ListTranscriptionRecordss(\n    $filter: ModelTranscriptionRecordsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listTranscriptionRecordss(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        spokenBy\n        content\n      }\n      nextToken\n    }\n  }\n',
 'listusedtogenhintalreadys': '\n  query ListUsedToGenHintAlreadys(\n    $filter: ModelUsedToGenHintAlreadyFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUsedToGenHintAlreadys(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        investigationId\n        commands\n        text\n      }\n      nextToken\n    }\n  }\n',
 'listuseractivitys': '\n  query ListUserActivitys(\n    $filter: ModelUserActivityFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUserActivitys(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        userID\n        status\n        investigationID\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listusers': '\n  query ListUsers(\n    $filter: ModelUserFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUsers(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n      nextToken\n    }\n  }\n',
 'listusersettinglabellinks': '\n  query ListUserSettingLabelLinks(\n    $filter: ModelUserSettingLabelLinkFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUserSettingLabelLinks(\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userSettingId\n        labelID\n        type\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'listusersettings': '\n  query ListUserSettings(\n    $filter: ModelUserSettingFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    listUserSettings(filter: $filter, limit: $limit, nextToken: $nextToken) {\n      items {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      nextToken\n    }\n  }\n',
 'msgsbycreatedat': '\n  query MsgsByCreatedAt(\n    $messageChannelId: ID\n    $createdAt: ModelStringKeyConditionInput\n    $sortDirection: ModelSortDirection\n    $filter: ModelMessageFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    msgsByCreatedAt(\n      messageChannelId: $messageChannelId\n      createdAt: $createdAt\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        authorId\n        content\n        type\n        messageChannelId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'searchallrunbookss': '\n  query SearchAllRunbookss(\n    $filter: SearchableAllRunbooksFilterInput\n    $sort: SearchableAllRunbooksSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchAllRunbookss(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchcheatsheets': '\n  query SearchCheatSheets(\n    $filter: SearchableCheatSheetFilterInput\n    $sort: SearchableCheatSheetSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchCheatSheets(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        title\n        author\n        content\n        type\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchchecklistitems': '\n  query SearchCheckListItems(\n    $filter: SearchableCheckListItemFilterInput\n    $sort: SearchableCheckListItemSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchCheckListItems(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchchecklists': '\n  query SearchCheckLists(\n    $filter: SearchableCheckListFilterInput\n    $sort: SearchableCheckListSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchCheckLists(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchepicautocompletes': '\n  query SearchEpicAutoCompletes(\n    $filter: SearchableepicAutoCompleteFilterInput\n    $sort: SearchableepicAutoCompleteSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchEpicAutoCompletes(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        author\n        cliCommand\n        command\n        createdAt\n        updatedAt\n        investigationId\n        times\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchinvestigationguestuserlinks': '\n  query SearchInvestigationGuestUserLinks(\n    $filter: SearchableInvestigationGuestUserLinkFilterInput\n    $sort: SearchableInvestigationGuestUserLinkSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchInvestigationGuestUserLinks(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userName\n        createdAt\n        updatedAt\n        investigationID\n        channelID\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchleadboardnodes': '\n  query SearchLeadBoardNodes(\n    $filter: SearchableLeadBoardNodeFilterInput\n    $sort: SearchableLeadBoardNodeSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchLeadBoardNodes(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchreportsummaryeditors': '\n  query SearchReportSummaryEditors(\n    $filter: SearchableReportSummaryEditorFilterInput\n    $sort: SearchableReportSummaryEditorSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchReportSummaryEditors(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        author\n        content\n        type\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchstashs': '\n  query SearchStashs(\n    $filter: SearchableStashFilterInput\n    $sort: SearchableStashSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchStashs(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        Key\n        Value\n        createdAt\n        updatedAt\n        author\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchsummaryinvestigations': '\n  query SearchSummaryInvestigations(\n    $filter: SearchableSummaryInvestigationFilterInput\n    $sort: SearchableSummaryInvestigationSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchSummaryInvestigations(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        createdAt\n        updatedAt\n        resolvedTime\n        OriginalID\n        title\n        HumanID\n        Commands\n        InvestigationEvents\n        CompleteInvestigationEvents\n        Participants\n        Comments\n        Pins\n        AvailableRunbooks\n        UsedRunbooks\n        Hints\n        Symptoms\n        owner\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchtenantcustomers': '\n  query SearchTenantCustomers(\n    $filter: SearchableTenantCustomerFilterInput\n    $sort: SearchableTenantCustomerSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchTenantCustomers(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        label\n        impactLabels\n        createdAt\n        updatedAt\n        customerName\n        email\n        phoneno\n        SLAType\n        city\n        state\n        contry\n        zipcode\n      }\n      nextToken\n      total\n    }\n  }\n',
 'searchtranscriptionrecordss': '\n  query SearchTranscriptionRecordss(\n    $filter: SearchableTranscriptionRecordsFilterInput\n    $sort: SearchableTranscriptionRecordsSortInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    searchTranscriptionRecordss(\n      filter: $filter\n      sort: $sort\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        spokenBy\n        content\n      }\n      nextToken\n      total\n    }\n  }\n',
 'slackinfoforappsyncuser': '\n  query SlackInfoForAppSyncUser(\n    $userAppSyncId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelSlackUserInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    SlackInfoForAppSyncUser(\n      userAppSyncId: $userAppSyncId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userAppSyncId\n        userName\n        userId\n        userScope\n        userToken\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'slackteaminfoforbot': '\n  query SlackTeamInfoForBot(\n    $botId: String\n    $sortDirection: ModelSortDirection\n    $filter: ModelSlackTeamInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    SlackTeamInfoForBot(\n      botId: $botId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        owner\n        teamId\n        teamName\n        slackAppId\n        botId\n        botToken\n        botScope\n        enterprise\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'slackuserinfo': '\n  query SlackUserInfo(\n    $userId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelSlackUserInfoFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    SlackUserInfo(\n      userId: $userId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userAppSyncId\n        userName\n        userId\n        userScope\n        userToken\n        slackAppId\n        slackTeamId\n        createdAt\n        updatedAt\n      }\n      nextToken\n    }\n  }\n',
 'statebyibid': '\n  query StateByIbid(\n    $investigationId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelStateFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    stateByIBID(\n      investigationId: $investigationId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        name\n        createdAt\n        updatedAt\n        author\n        lastState\n        investigationId\n      }\n      nextToken\n    }\n  }\n',
 'trbyinvestigationid': '\n  query TrByInvestigationId(\n    $investigationId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelTranscriptionRecordsFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    trByInvestigationId(\n      investigationId: $investigationId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        investigationId\n        createdAt\n        updatedAt\n        spokenBy\n        content\n      }\n      nextToken\n    }\n  }\n',
 'userbyemail': '\n  query UserByEmail(\n    $email: String\n    $sortDirection: ModelSortDirection\n    $filter: ModelUserFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    UserByEmail(\n      email: $email\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n      nextToken\n    }\n  }\n',
 'usersettingbyuser': '\n  query UserSettingByUser(\n    $userId: ID\n    $sortDirection: ModelSortDirection\n    $filter: ModelUserSettingFilterInput\n    $limit: Int\n    $nextToken: String\n  ) {\n    userSettingByUser(\n      userId: $userId\n      sortDirection: $sortDirection\n      filter: $filter\n      limit: $limit\n      nextToken: $nextToken\n    ) {\n      items {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      nextToken\n    }\n  }\n'}



from setuptools import setup, find_packages
from os import path
from io import open

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='epiphani-ecube',
    version='1.0.3',
    license='MIT',
    scripts=['e3'],
    install_requires=[
        'tabulate',
        'PyYAML',
        'Jinja2',
        'websocket-client>=0.57.0',
        'warrant>=0.6.1',
        'configparser',
        'requests',
        'epiphani-appsync-subscription-manager>=0.1.0',
    ],
    python_requires='>=2.7',
    author='Praveen Madhav',
    author_email='praveen@epiphani.io',
    url='https://github.com/epiphani-inc/ecube',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(include=["ecube", "ecube.*"]),
    include_package_data=True,
    description="epiphani CLI for registering connectors & executing scripts in a sandbox",
)




'''
Copyright (c) 2020 epiphani, Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
'''
import argparse
import configparser
import sys
from ecube.run import Run
from ecube.playbook import Playbook

import os
import ecube.gql as gql

DEFAULT_ENV = 'ALPHA'

class MyParser(object):

    def __init__(self):
        self.config_args = {}
        parser = argparse.ArgumentParser(
            description='e3 (ecube) -> epiphani execution engine',
            usage='''e3 <command> [<args>]
The following commands are supported:
    run      Run a local connector
    runcli   Run a cli as a connector 
    playbook Interact with the playbook engine 
    
Please create a config file ~/.e3.ini with following content:
[DEFAULT]
username = <epiphani username> <REQUIRED>
password = <epiphani password> <REQUIRED>
login = URL to epiphani <OPTIONAL>
log_file = foo.log <OPTIONAL>
''')
        config = configparser.ConfigParser()
        FN = os.path.expanduser('~/.e3.ini')
        config.read(FN)
        for key in config['DEFAULT']:
            self.config_args[key] = config['DEFAULT'][key]
        if not self.config_args.get('login'):
            self.config_args['login'] = DEFAULT_ENV
        if not self.config_args.get('username') or not self.config_args.get('password'):
            print("Missing config")
            parser.print_help()
            exit(1)
        tmp_user_list = [{'username': self.config_args['username'], 'passwd': self.config_args['password']}]
        gql.set_env_var(self.config_args['login'], 'USERS', tmp_user_list)
        parser.add_argument('command', help='Subcommand to run')
        # parse_args defaults to [1:] for args, but you need to
        # exclude the rest of the args too, or validation will fail
        args = parser.parse_args(sys.argv[1:2])
        if not hasattr(self, args.command):
            print('Unrecognized command')
            parser.print_help()
            exit(1)
        # use dispatch pattern to invoke method with same name
        getattr(self, args.command)()

    def addKeys(self, args):
        d = vars(args)
        for key in self.config_args:
            d[key] = self.config_args[key]

    def run(self):
        parser = argparse.ArgumentParser(description='Run the commands')
        parser.add_argument('--directory', required=True, help='the path to the connector')
        parser.add_argument('--publish-playbooks', required=False,
            help="Only publish the playbooks (as epiphani, not developer) and exit",
            default=False, action='store_true')
        args = parser.parse_args(sys.argv[2:])
        self.addKeys(args)
        runCommand(args)
    def runcli(self):
        parser = argparse.ArgumentParser(description='Run the commands')
        parser.add_argument('--name', required=True, help='the name of the connector to create')
        args = parser.parse_args(sys.argv[2:])

        self.addKeys(args)
        runCLI(args)
    def playbook(self):
        parser = argparse.ArgumentParser(
            description="playbook sub commands")
        s1 = parser.add_subparsers(title="commands", dest="command")
        s1.add_parser("show", help="show all the playbooks")
        pbn = s1.add_parser("run", help="run the playbooks")
        pbn.add_argument('--name',  dest="PBName", required=True, help='the name of the playbook to run')
        pbn.add_argument('--vars',  dest="PBVars", required=False, help='the variables to pass to playbook')
        pbn.add_argument('--json',  type=bool, required=False, help='output only json', default=False)

        args = parser.parse_args(sys.argv[2:])
        self.addKeys(args)
        playBook(args)

def runCommand(args):
    #validate args 
    x = Run(args)
    x.Execute()

def runCLI(args):
    #validate args 
    x = Run(args)
    x.ExecuteCLI()

def playBook(args):
    x = Playbook(args)
    getattr(x, args.command)()

def main():
    MyParser()



# This is an auto-generated file, please do not modify

SUBSCRIPTIONS = {'oncreateallrunbooks': '\n  subscription OnCreateAllRunbooks {\n    onCreateAllRunbooks {\n      id\n      name\n      description\n      content\n      author\n      commands\n      createdAt\n      updatedAt\n      RunBookConnectors\n      type\n      longSave\n      rbVars\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      connectorForms {\n        nextToken\n      }\n    }\n  }\n',
 'oncreateallworkflows': '\n  subscription OnCreateAllWorkflows {\n    onCreateAllWorkflows {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      author\n      longSave\n      rbVars\n    }\n  }\n',
 'oncreatechannel': '\n  subscription OnCreateChannel {\n    onCreateChannel {\n      id\n      messages {\n        nextToken\n      }\n      associated {\n        nextToken\n      }\n      name\n      title\n      members\n      membersState\n      createdAt\n      updatedAt\n      memberLocation\n    }\n  }\n',
 'oncreatechat': '\n  subscription OnCreateChat {\n    onCreateChat {\n      id\n      from\n      content\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreatecheatsheet': '\n  subscription OnCreateCheatSheet {\n    onCreateCheatSheet {\n      id\n      createdAt\n      updatedAt\n      title\n      author\n      content\n      type\n    }\n  }\n',
 'oncreatechecklist': '\n  subscription OnCreateCheckList {\n    onCreateCheckList {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      content\n      author\n      CheckListLink {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n    }\n  }\n',
 'oncreatechecklistinvlink': '\n  subscription OnCreateCheckListInvLink($owner: String) {\n    onCreateCheckListInvLink(owner: $owner) {\n      id\n      createdAt\n      updatedAt\n      investigationID\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      owner\n    }\n  }\n',
 'oncreatechecklistitem': '\n  subscription OnCreateCheckListItem {\n    onCreateCheckListItem {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      type\n      connection\n      MMNodeConnection\n      investigationID\n      assignee\n      associatedPlaybooks\n      associatedCommands\n      CheckListLink {\n        nextToken\n      }\n    }\n  }\n',
 'oncreateclick': '\n  subscription OnCreateClick {\n    onCreateClick {\n      id\n      count\n      type\n      featureName\n      createdAt\n      updatedAt\n      readAt\n    }\n  }\n',
 'oncreateclicllink': '\n  subscription OnCreateCliclLink($author: String) {\n    onCreateCLICLLink(author: $author) {\n      id\n      createdAt\n      updatedAt\n      CheckListItemID\n      lane\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      CheckListItem {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n    }\n  }\n',
 'oncreatecommands': '\n  subscription OnCreateCommands {\n    onCreateCommands {\n      id\n      from\n      mode\n      command\n      output\n      state\n      returnCode\n      investigationId\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreatecomment': '\n  subscription OnCreateComment {\n    onCreateComment {\n      id\n      parent\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreateconferenceconfig': '\n  subscription OnCreateConferenceConfig {\n    onCreateConferenceConfig {\n      id\n      url\n      userName\n      password\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreateconnectorform': '\n  subscription OnCreateConnectorForm {\n    onCreateConnectorForm {\n      id\n      createdAt\n      updatedAt\n      name\n      owner\n      connectorID\n      connector {\n        id\n        createdAt\n        updatedAt\n        category\n        name\n        owner\n        description\n        detaileddescription\n        iconPath\n        version\n        md5\n        source\n        configuration\n        commands\n        commandsType\n        script\n        scriptType\n        scriptPath\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      configData\n      commandData\n      nodeData\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      runbooks {\n        nextToken\n      }\n    }\n  }\n',
 'oncreateconnectors': '\n  subscription OnCreateConnectors {\n    onCreateConnectors {\n      id\n      createdAt\n      updatedAt\n      category\n      name\n      owner\n      description\n      detaileddescription\n      iconPath\n      version\n      md5\n      source\n      configuration\n      commands\n      commandsType\n      script\n      scriptType\n      scriptPath\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'oncreatedashboardconfig': '\n  subscription OnCreateDashboardConfig {\n    onCreateDashboardConfig {\n      id\n      url\n      labels {\n        nextToken\n      }\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreateecubesandboxexecution': '\n  subscription OnCreateEcubeSandboxExecution {\n    onCreateEcubeSandboxExecution {\n      id\n      owner\n      output\n      outputType\n      returnCode\n      status\n      createdAt\n      updatedAt\n      E3One\n      E3Two\n      E3Three\n    }\n  }\n',
 'oncreateepicautocomplete': '\n  subscription OnCreateEpicAutoComplete($author: String) {\n    onCreateEpicAutoComplete(author: $author) {\n      id\n      author\n      cliCommand\n      command\n      createdAt\n      updatedAt\n      investigationId\n      times\n    }\n  }\n',
 'oncreateepiclicommand': '\n  subscription OnCreateEpicliCommand {\n    onCreateEPICLICommand {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'oncreateexecutedrunbooks': '\n  subscription OnCreateExecutedRunbooks {\n    onCreateExecutedRunbooks {\n      id\n      createdAt\n      updatedAt\n      runbookID\n      investigationId\n      output\n      outputType\n      title\n      state\n      author\n      rbVars\n      callbackUrl\n      callbackData\n      source\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'oncreateexecutedworkflowstate': '\n  subscription OnCreateExecutedWorkflowState {\n    onCreateExecutedWorkflowState {\n      id\n      createdAt\n      updatedAt\n      name\n      state\n      output\n      type\n      allworkflowID\n      investigationID\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreategroupmember': '\n  subscription OnCreateGroupMember {\n    onCreateGroupMember {\n      id\n      hostId\n      groupId\n      host {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        host\n        port\n        vars\n      }\n      group {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        name\n        groups\n        port\n        vars\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreateguardrail': '\n  subscription OnCreateGuardRail {\n    onCreateGuardRail {\n      id\n      timeOut\n      message\n      labels {\n        nextToken\n      }\n      author\n      active\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreatehint': '\n  subscription OnCreateHint {\n    onCreateHint {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      type\n      connection\n      pastInvestigationID\n      title\n      importance\n      starrted\n      applied\n      url\n      why\n    }\n  }\n',
 'oncreateinventory': '\n  subscription OnCreateInventory {\n    onCreateInventory {\n      id\n      createdAt\n      updatedAt\n      author\n      name\n      all {\n        nextToken\n      }\n      groups {\n        nextToken\n      }\n      vars\n    }\n  }\n',
 'oncreateinventorygroup': '\n  subscription OnCreateInventoryGroup {\n    onCreateInventoryGroup {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      name\n      hosts {\n        nextToken\n      }\n      groups\n      port\n      vars\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'oncreateinventoryhost': '\n  subscription OnCreateInventoryHost {\n    onCreateInventoryHost {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      host\n      port\n      vars\n      groups {\n        nextToken\n      }\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'oncreateinvestigation': '\n  subscription OnCreateInvestigation {\n    onCreateInvestigation {\n      id\n      title\n      from\n      createdAt\n      currentState\n      HumanID\n      currentStateID\n      severity\n      priority\n      location\n      labels {\n        nextToken\n      }\n      channelId\n      investigationChannel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      updatedAt\n      resolvedTime\n      resolvedComment\n      Symptoms\n      MMNodeLinks {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n      meetingType\n      meetingId\n    }\n  }\n',
 'oncreateinvestigationevent': '\n  subscription OnCreateInvestigationEvent {\n    onCreateInvestigationEvent {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreateinvestigationguestuserlink': '\n  subscription OnCreateInvestigationGuestUserLink {\n    onCreateInvestigationGuestUserLink {\n      id\n      userName\n      createdAt\n      updatedAt\n      investigationID\n      channelID\n    }\n  }\n',
 'oncreatelabel': '\n  subscription OnCreateLabel {\n    onCreateLabel {\n      id\n      name\n      color\n      type\n      investigations {\n        nextToken\n      }\n      userSettings {\n        nextToken\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreateleadboard': '\n  subscription OnCreateLeadBoard {\n    onCreateLeadBoard {\n      id\n      investigationId\n      content\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreateleadboardnode': '\n  subscription OnCreateLeadBoardNode {\n    onCreateLeadBoardNode {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      notes\n      associatedPlaybooks\n      associatedCommands\n      InvestLinks {\n        nextToken\n      }\n    }\n  }\n',
 'oncreatemessage': '\n  subscription OnCreateMessage {\n    onCreateMessage {\n      id\n      authorId\n      content\n      type\n      channel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      messageChannelId\n      createdAt\n      updatedAt\n      author {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'oncreatemmnodelink': '\n  subscription OnCreateMmNodeLink {\n    onCreateMMNodeLink {\n      id\n      createdAt\n      updatedAt\n      assigned\n      state\n      content\n      author\n      investigationID\n      connectionToTask\n      LBNID\n      LeadBoardNodeId {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      investigationId {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreatenotification': '\n  subscription OnCreateNotification {\n    onCreateNotification {\n      id\n      userName\n      content\n      containerType\n      containerId\n      investigationId\n      isViewed\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreatepin': '\n  subscription OnCreatePin {\n    onCreatePin {\n      id\n      imageId\n      content\n      createdAt\n      updatedAt\n      author\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreateprivatekey': '\n  subscription OnCreatePrivateKey {\n    onCreatePrivateKey {\n      id\n      sshKey\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreateremotecontrol': '\n  subscription OnCreateRemoteControl {\n    onCreateRemoteControl {\n      id\n      from\n      to\n      command\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreatereportsummaryeditor': '\n  subscription OnCreateReportSummaryEditor {\n    onCreateReportSummaryEditor {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'oncreaterunbookconnectorformlink': '\n  subscription OnCreateRunbookConnectorFormLink {\n    onCreateRunbookConnectorFormLink {\n      id\n      connectorFormId\n      runbookId\n      connectorForm {\n        id\n        createdAt\n        updatedAt\n        name\n        owner\n        connectorID\n        configData\n        commandData\n        nodeData\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      createdAt\n      updatedAt\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'oncreateschedpbs': '\n  subscription OnCreateSchedPBs {\n    onCreateSchedPBs {\n      id\n      pbId\n      frequency\n      pbName\n      rbVars\n      scheduled\n      createdAt\n      updatedAt\n      author\n    }\n  }\n',
 'oncreatesshtabs': '\n  subscription OnCreateSshTabs {\n    onCreateSshTabs {\n      id\n      investigationId\n      host\n      author\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'oncreatestash': '\n  subscription OnCreateStash {\n    onCreateStash {\n      id\n      Key\n      Value\n      createdAt\n      updatedAt\n      author\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'oncreatestate': '\n  subscription OnCreateState {\n    onCreateState {\n      id\n      name\n      createdAt\n      updatedAt\n      author\n      lastState\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreatesummaryinvestigation': '\n  subscription OnCreateSummaryInvestigation($owner: String) {\n    onCreateSummaryInvestigation(owner: $owner) {\n      id\n      createdAt\n      updatedAt\n      resolvedTime\n      OriginalID\n      title\n      HumanID\n      Commands\n      InvestigationEvents\n      CompleteInvestigationEvents\n      Participants\n      Comments\n      Pins\n      AvailableRunbooks\n      UsedRunbooks\n      Hints\n      Symptoms\n      owner\n    }\n  }\n',
 'oncreatetenantcustomer': '\n  subscription OnCreateTenantCustomer {\n    onCreateTenantCustomer {\n      label\n      impactLabels\n      createdAt\n      updatedAt\n      customerName\n      email\n      phoneno\n      SLAType\n      city\n      state\n      contry\n      zipcode\n    }\n  }\n',
 'oncreatetranscriptionrecords': '\n  subscription OnCreateTranscriptionRecords {\n    onCreateTranscriptionRecords {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      spokenBy\n      content\n    }\n  }\n',
 'oncreateusedtogenhintalready': '\n  subscription OnCreateUsedToGenHintAlready {\n    onCreateUsedToGenHintAlready {\n      id\n      createdAt\n      updatedAt\n      investigationId\n      commands\n      text\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'oncreateuser': '\n  subscription OnCreateUser($owner: String) {\n    onCreateUser(owner: $owner) {\n      id\n      username\n      email\n      firstname\n      lastname\n      avatar\n      mood\n      name\n      role\n      status\n      timezone\n      phone\n      address\n      location\n      chatList {\n        nextToken\n      }\n      messages {\n        nextToken\n      }\n      createdAt\n      updatedAt\n      owner\n    }\n  }\n',
 'oncreateuseractivity': '\n  subscription OnCreateUserActivity {\n    onCreateUserActivity {\n      id\n      userID\n      status\n      investigationID\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      user {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'oncreateusersettinglabellink': '\n  subscription OnCreateUserSettingLabelLink {\n    onCreateUserSettingLabelLink {\n      id\n      userSettingId\n      userSetting {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      labelID\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      type\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeleteallrunbooks': '\n  subscription OnDeleteAllRunbooks {\n    onDeleteAllRunbooks {\n      id\n      name\n      description\n      content\n      author\n      commands\n      createdAt\n      updatedAt\n      RunBookConnectors\n      type\n      longSave\n      rbVars\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      connectorForms {\n        nextToken\n      }\n    }\n  }\n',
 'ondeleteallworkflows': '\n  subscription OnDeleteAllWorkflows {\n    onDeleteAllWorkflows {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      author\n      longSave\n      rbVars\n    }\n  }\n',
 'ondeletechannel': '\n  subscription OnDeleteChannel {\n    onDeleteChannel {\n      id\n      messages {\n        nextToken\n      }\n      associated {\n        nextToken\n      }\n      name\n      title\n      members\n      membersState\n      createdAt\n      updatedAt\n      memberLocation\n    }\n  }\n',
 'ondeletechat': '\n  subscription OnDeleteChat {\n    onDeleteChat {\n      id\n      from\n      content\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeletecheatsheet': '\n  subscription OnDeleteCheatSheet {\n    onDeleteCheatSheet {\n      id\n      createdAt\n      updatedAt\n      title\n      author\n      content\n      type\n    }\n  }\n',
 'ondeletechecklist': '\n  subscription OnDeleteCheckList {\n    onDeleteCheckList {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      content\n      author\n      CheckListLink {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n    }\n  }\n',
 'ondeletechecklistinvlink': '\n  subscription OnDeleteCheckListInvLink($owner: String) {\n    onDeleteCheckListInvLink(owner: $owner) {\n      id\n      createdAt\n      updatedAt\n      investigationID\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      owner\n    }\n  }\n',
 'ondeletechecklistitem': '\n  subscription OnDeleteCheckListItem {\n    onDeleteCheckListItem {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      type\n      connection\n      MMNodeConnection\n      investigationID\n      assignee\n      associatedPlaybooks\n      associatedCommands\n      CheckListLink {\n        nextToken\n      }\n    }\n  }\n',
 'ondeleteclick': '\n  subscription OnDeleteClick {\n    onDeleteClick {\n      id\n      count\n      type\n      featureName\n      createdAt\n      updatedAt\n      readAt\n    }\n  }\n',
 'ondeleteclicllink': '\n  subscription OnDeleteCliclLink($author: String) {\n    onDeleteCLICLLink(author: $author) {\n      id\n      createdAt\n      updatedAt\n      CheckListItemID\n      lane\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      CheckListItem {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n    }\n  }\n',
 'ondeletecommands': '\n  subscription OnDeleteCommands {\n    onDeleteCommands {\n      id\n      from\n      mode\n      command\n      output\n      state\n      returnCode\n      investigationId\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeletecomment': '\n  subscription OnDeleteComment {\n    onDeleteComment {\n      id\n      parent\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeleteconferenceconfig': '\n  subscription OnDeleteConferenceConfig {\n    onDeleteConferenceConfig {\n      id\n      url\n      userName\n      password\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeleteconnectorform': '\n  subscription OnDeleteConnectorForm {\n    onDeleteConnectorForm {\n      id\n      createdAt\n      updatedAt\n      name\n      owner\n      connectorID\n      connector {\n        id\n        createdAt\n        updatedAt\n        category\n        name\n        owner\n        description\n        detaileddescription\n        iconPath\n        version\n        md5\n        source\n        configuration\n        commands\n        commandsType\n        script\n        scriptType\n        scriptPath\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      configData\n      commandData\n      nodeData\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      runbooks {\n        nextToken\n      }\n    }\n  }\n',
 'ondeleteconnectors': '\n  subscription OnDeleteConnectors {\n    onDeleteConnectors {\n      id\n      createdAt\n      updatedAt\n      category\n      name\n      owner\n      description\n      detaileddescription\n      iconPath\n      version\n      md5\n      source\n      configuration\n      commands\n      commandsType\n      script\n      scriptType\n      scriptPath\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'ondeletedashboardconfig': '\n  subscription OnDeleteDashboardConfig {\n    onDeleteDashboardConfig {\n      id\n      url\n      labels {\n        nextToken\n      }\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeleteecubesandboxexecution': '\n  subscription OnDeleteEcubeSandboxExecution {\n    onDeleteEcubeSandboxExecution {\n      id\n      owner\n      output\n      outputType\n      returnCode\n      status\n      createdAt\n      updatedAt\n      E3One\n      E3Two\n      E3Three\n    }\n  }\n',
 'ondeleteepicautocomplete': '\n  subscription OnDeleteEpicAutoComplete($author: String) {\n    onDeleteEpicAutoComplete(author: $author) {\n      id\n      author\n      cliCommand\n      command\n      createdAt\n      updatedAt\n      investigationId\n      times\n    }\n  }\n',
 'ondeleteepiclicommand': '\n  subscription OnDeleteEpicliCommand {\n    onDeleteEPICLICommand {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'ondeleteexecutedrunbooks': '\n  subscription OnDeleteExecutedRunbooks {\n    onDeleteExecutedRunbooks {\n      id\n      createdAt\n      updatedAt\n      runbookID\n      investigationId\n      output\n      outputType\n      title\n      state\n      author\n      rbVars\n      callbackUrl\n      callbackData\n      source\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'ondeleteexecutedworkflowstate': '\n  subscription OnDeleteExecutedWorkflowState {\n    onDeleteExecutedWorkflowState {\n      id\n      createdAt\n      updatedAt\n      name\n      state\n      output\n      type\n      allworkflowID\n      investigationID\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeletegroupmember': '\n  subscription OnDeleteGroupMember {\n    onDeleteGroupMember {\n      id\n      hostId\n      groupId\n      host {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        host\n        port\n        vars\n      }\n      group {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        name\n        groups\n        port\n        vars\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeleteguardrail': '\n  subscription OnDeleteGuardRail {\n    onDeleteGuardRail {\n      id\n      timeOut\n      message\n      labels {\n        nextToken\n      }\n      author\n      active\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeletehint': '\n  subscription OnDeleteHint {\n    onDeleteHint {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      type\n      connection\n      pastInvestigationID\n      title\n      importance\n      starrted\n      applied\n      url\n      why\n    }\n  }\n',
 'ondeleteinventory': '\n  subscription OnDeleteInventory {\n    onDeleteInventory {\n      id\n      createdAt\n      updatedAt\n      author\n      name\n      all {\n        nextToken\n      }\n      groups {\n        nextToken\n      }\n      vars\n    }\n  }\n',
 'ondeleteinventorygroup': '\n  subscription OnDeleteInventoryGroup {\n    onDeleteInventoryGroup {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      name\n      hosts {\n        nextToken\n      }\n      groups\n      port\n      vars\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'ondeleteinventoryhost': '\n  subscription OnDeleteInventoryHost {\n    onDeleteInventoryHost {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      host\n      port\n      vars\n      groups {\n        nextToken\n      }\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'ondeleteinvestigation': '\n  subscription OnDeleteInvestigation {\n    onDeleteInvestigation {\n      id\n      title\n      from\n      createdAt\n      currentState\n      HumanID\n      currentStateID\n      severity\n      priority\n      location\n      labels {\n        nextToken\n      }\n      channelId\n      investigationChannel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      updatedAt\n      resolvedTime\n      resolvedComment\n      Symptoms\n      MMNodeLinks {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n      meetingType\n      meetingId\n    }\n  }\n',
 'ondeleteinvestigationevent': '\n  subscription OnDeleteInvestigationEvent {\n    onDeleteInvestigationEvent {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeleteinvestigationguestuserlink': '\n  subscription OnDeleteInvestigationGuestUserLink {\n    onDeleteInvestigationGuestUserLink {\n      id\n      userName\n      createdAt\n      updatedAt\n      investigationID\n      channelID\n    }\n  }\n',
 'ondeletelabel': '\n  subscription OnDeleteLabel {\n    onDeleteLabel {\n      id\n      name\n      color\n      type\n      investigations {\n        nextToken\n      }\n      userSettings {\n        nextToken\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeleteleadboard': '\n  subscription OnDeleteLeadBoard {\n    onDeleteLeadBoard {\n      id\n      investigationId\n      content\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeleteleadboardnode': '\n  subscription OnDeleteLeadBoardNode {\n    onDeleteLeadBoardNode {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      notes\n      associatedPlaybooks\n      associatedCommands\n      InvestLinks {\n        nextToken\n      }\n    }\n  }\n',
 'ondeletemessage': '\n  subscription OnDeleteMessage {\n    onDeleteMessage {\n      id\n      authorId\n      content\n      type\n      channel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      messageChannelId\n      createdAt\n      updatedAt\n      author {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'ondeletemmnodelink': '\n  subscription OnDeleteMmNodeLink {\n    onDeleteMMNodeLink {\n      id\n      createdAt\n      updatedAt\n      assigned\n      state\n      content\n      author\n      investigationID\n      connectionToTask\n      LBNID\n      LeadBoardNodeId {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      investigationId {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeletenotification': '\n  subscription OnDeleteNotification {\n    onDeleteNotification {\n      id\n      userName\n      content\n      containerType\n      containerId\n      investigationId\n      isViewed\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeletepin': '\n  subscription OnDeletePin {\n    onDeletePin {\n      id\n      imageId\n      content\n      createdAt\n      updatedAt\n      author\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeleteprivatekey': '\n  subscription OnDeletePrivateKey {\n    onDeletePrivateKey {\n      id\n      sshKey\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeleteremotecontrol': '\n  subscription OnDeleteRemoteControl {\n    onDeleteRemoteControl {\n      id\n      from\n      to\n      command\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeletereportsummaryeditor': '\n  subscription OnDeleteReportSummaryEditor {\n    onDeleteReportSummaryEditor {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'ondeleterunbookconnectorformlink': '\n  subscription OnDeleteRunbookConnectorFormLink {\n    onDeleteRunbookConnectorFormLink {\n      id\n      connectorFormId\n      runbookId\n      connectorForm {\n        id\n        createdAt\n        updatedAt\n        name\n        owner\n        connectorID\n        configData\n        commandData\n        nodeData\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      createdAt\n      updatedAt\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'ondeleteschedpbs': '\n  subscription OnDeleteSchedPBs {\n    onDeleteSchedPBs {\n      id\n      pbId\n      frequency\n      pbName\n      rbVars\n      scheduled\n      createdAt\n      updatedAt\n      author\n    }\n  }\n',
 'ondeletesshtabs': '\n  subscription OnDeleteSshTabs {\n    onDeleteSshTabs {\n      id\n      investigationId\n      host\n      author\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'ondeletestash': '\n  subscription OnDeleteStash {\n    onDeleteStash {\n      id\n      Key\n      Value\n      createdAt\n      updatedAt\n      author\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'ondeletestate': '\n  subscription OnDeleteState {\n    onDeleteState {\n      id\n      name\n      createdAt\n      updatedAt\n      author\n      lastState\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeletesummaryinvestigation': '\n  subscription OnDeleteSummaryInvestigation($owner: String) {\n    onDeleteSummaryInvestigation(owner: $owner) {\n      id\n      createdAt\n      updatedAt\n      resolvedTime\n      OriginalID\n      title\n      HumanID\n      Commands\n      InvestigationEvents\n      CompleteInvestigationEvents\n      Participants\n      Comments\n      Pins\n      AvailableRunbooks\n      UsedRunbooks\n      Hints\n      Symptoms\n      owner\n    }\n  }\n',
 'ondeletetenantcustomer': '\n  subscription OnDeleteTenantCustomer {\n    onDeleteTenantCustomer {\n      label\n      impactLabels\n      createdAt\n      updatedAt\n      customerName\n      email\n      phoneno\n      SLAType\n      city\n      state\n      contry\n      zipcode\n    }\n  }\n',
 'ondeletetranscriptionrecords': '\n  subscription OnDeleteTranscriptionRecords {\n    onDeleteTranscriptionRecords {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      spokenBy\n      content\n    }\n  }\n',
 'ondeleteusedtogenhintalready': '\n  subscription OnDeleteUsedToGenHintAlready {\n    onDeleteUsedToGenHintAlready {\n      id\n      createdAt\n      updatedAt\n      investigationId\n      commands\n      text\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'ondeleteuser': '\n  subscription OnDeleteUser($owner: String) {\n    onDeleteUser(owner: $owner) {\n      id\n      username\n      email\n      firstname\n      lastname\n      avatar\n      mood\n      name\n      role\n      status\n      timezone\n      phone\n      address\n      location\n      chatList {\n        nextToken\n      }\n      messages {\n        nextToken\n      }\n      createdAt\n      updatedAt\n      owner\n    }\n  }\n',
 'ondeleteuseractivity': '\n  subscription OnDeleteUserActivity {\n    onDeleteUserActivity {\n      id\n      userID\n      status\n      investigationID\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      user {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'ondeleteusersettinglabellink': '\n  subscription OnDeleteUserSettingLabelLink {\n    onDeleteUserSettingLabelLink {\n      id\n      userSettingId\n      userSetting {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      labelID\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      type\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdateallrunbooks': '\n  subscription OnUpdateAllRunbooks {\n    onUpdateAllRunbooks {\n      id\n      name\n      description\n      content\n      author\n      commands\n      createdAt\n      updatedAt\n      RunBookConnectors\n      type\n      longSave\n      rbVars\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      connectorForms {\n        nextToken\n      }\n    }\n  }\n',
 'onupdateallworkflows': '\n  subscription OnUpdateAllWorkflows {\n    onUpdateAllWorkflows {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      author\n      longSave\n      rbVars\n    }\n  }\n',
 'onupdatechannel': '\n  subscription OnUpdateChannel {\n    onUpdateChannel {\n      id\n      messages {\n        nextToken\n      }\n      associated {\n        nextToken\n      }\n      name\n      title\n      members\n      membersState\n      createdAt\n      updatedAt\n      memberLocation\n    }\n  }\n',
 'onupdatechat': '\n  subscription OnUpdateChat {\n    onUpdateChat {\n      id\n      from\n      content\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdatecheatsheet': '\n  subscription OnUpdateCheatSheet {\n    onUpdateCheatSheet {\n      id\n      createdAt\n      updatedAt\n      title\n      author\n      content\n      type\n    }\n  }\n',
 'onupdatechecklist': '\n  subscription OnUpdateCheckList {\n    onUpdateCheckList {\n      id\n      createdAt\n      updatedAt\n      name\n      description\n      type\n      content\n      author\n      CheckListLink {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n    }\n  }\n',
 'onupdatechecklistinvlink': '\n  subscription OnUpdateCheckListInvLink($owner: String) {\n    onUpdateCheckListInvLink(owner: $owner) {\n      id\n      createdAt\n      updatedAt\n      investigationID\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      owner\n    }\n  }\n',
 'onupdatechecklistitem': '\n  subscription OnUpdateCheckListItem {\n    onUpdateCheckListItem {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      type\n      connection\n      MMNodeConnection\n      investigationID\n      assignee\n      associatedPlaybooks\n      associatedCommands\n      CheckListLink {\n        nextToken\n      }\n    }\n  }\n',
 'onupdateclick': '\n  subscription OnUpdateClick {\n    onUpdateClick {\n      id\n      count\n      type\n      featureName\n      createdAt\n      updatedAt\n      readAt\n    }\n  }\n',
 'onupdateclicllink': '\n  subscription OnUpdateCliclLink($author: String) {\n    onUpdateCLICLLink(author: $author) {\n      id\n      createdAt\n      updatedAt\n      CheckListItemID\n      lane\n      CheckListID\n      CheckList {\n        id\n        createdAt\n        updatedAt\n        name\n        description\n        type\n        content\n        author\n      }\n      CheckListItem {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        type\n        connection\n        MMNodeConnection\n        investigationID\n        assignee\n        associatedPlaybooks\n        associatedCommands\n      }\n    }\n  }\n',
 'onupdatecommands': '\n  subscription OnUpdateCommands {\n    onUpdateCommands {\n      id\n      from\n      mode\n      command\n      output\n      state\n      returnCode\n      investigationId\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdatecomment': '\n  subscription OnUpdateComment {\n    onUpdateComment {\n      id\n      parent\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdateconferenceconfig': '\n  subscription OnUpdateConferenceConfig {\n    onUpdateConferenceConfig {\n      id\n      url\n      userName\n      password\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdateconnectorform': '\n  subscription OnUpdateConnectorForm {\n    onUpdateConnectorForm {\n      id\n      createdAt\n      updatedAt\n      name\n      owner\n      connectorID\n      connector {\n        id\n        createdAt\n        updatedAt\n        category\n        name\n        owner\n        description\n        detaileddescription\n        iconPath\n        version\n        md5\n        source\n        configuration\n        commands\n        commandsType\n        script\n        scriptType\n        scriptPath\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      configData\n      commandData\n      nodeData\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n      runbooks {\n        nextToken\n      }\n    }\n  }\n',
 'onupdateconnectors': '\n  subscription OnUpdateConnectors {\n    onUpdateConnectors {\n      id\n      createdAt\n      updatedAt\n      category\n      name\n      owner\n      description\n      detaileddescription\n      iconPath\n      version\n      md5\n      source\n      configuration\n      commands\n      commandsType\n      script\n      scriptType\n      scriptPath\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'onupdatedashboardconfig': '\n  subscription OnUpdateDashboardConfig {\n    onUpdateDashboardConfig {\n      id\n      url\n      labels {\n        nextToken\n      }\n      author\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdateecubesandboxexecution': '\n  subscription OnUpdateEcubeSandboxExecution {\n    onUpdateEcubeSandboxExecution {\n      id\n      owner\n      output\n      outputType\n      returnCode\n      status\n      createdAt\n      updatedAt\n      E3One\n      E3Two\n      E3Three\n    }\n  }\n',
 'onupdateepicautocomplete': '\n  subscription OnUpdateEpicAutoComplete($author: String) {\n    onUpdateEpicAutoComplete(author: $author) {\n      id\n      author\n      cliCommand\n      command\n      createdAt\n      updatedAt\n      investigationId\n      times\n    }\n  }\n',
 'onupdateepiclicommand': '\n  subscription OnUpdateEpicliCommand {\n    onUpdateEPICLICommand {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'onupdateexecutedrunbooks': '\n  subscription OnUpdateExecutedRunbooks {\n    onUpdateExecutedRunbooks {\n      id\n      createdAt\n      updatedAt\n      runbookID\n      investigationId\n      output\n      outputType\n      title\n      state\n      author\n      rbVars\n      callbackUrl\n      callbackData\n      source\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'onupdateexecutedworkflowstate': '\n  subscription OnUpdateExecutedWorkflowState {\n    onUpdateExecutedWorkflowState {\n      id\n      createdAt\n      updatedAt\n      name\n      state\n      output\n      type\n      allworkflowID\n      investigationID\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdategroupmember': '\n  subscription OnUpdateGroupMember {\n    onUpdateGroupMember {\n      id\n      hostId\n      groupId\n      host {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        host\n        port\n        vars\n      }\n      group {\n        id\n        inventoryId\n        createdAt\n        updatedAt\n        author\n        name\n        groups\n        port\n        vars\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdateguardrail': '\n  subscription OnUpdateGuardRail {\n    onUpdateGuardRail {\n      id\n      timeOut\n      message\n      labels {\n        nextToken\n      }\n      author\n      active\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdatehint': '\n  subscription OnUpdateHint {\n    onUpdateHint {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      type\n      connection\n      pastInvestigationID\n      title\n      importance\n      starrted\n      applied\n      url\n      why\n    }\n  }\n',
 'onupdateinventory': '\n  subscription OnUpdateInventory {\n    onUpdateInventory {\n      id\n      createdAt\n      updatedAt\n      author\n      name\n      all {\n        nextToken\n      }\n      groups {\n        nextToken\n      }\n      vars\n    }\n  }\n',
 'onupdateinventorygroup': '\n  subscription OnUpdateInventoryGroup {\n    onUpdateInventoryGroup {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      name\n      hosts {\n        nextToken\n      }\n      groups\n      port\n      vars\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'onupdateinventoryhost': '\n  subscription OnUpdateInventoryHost {\n    onUpdateInventoryHost {\n      id\n      inventoryId\n      createdAt\n      updatedAt\n      author\n      host\n      port\n      vars\n      groups {\n        nextToken\n      }\n      inventory {\n        id\n        createdAt\n        updatedAt\n        author\n        name\n        vars\n      }\n    }\n  }\n',
 'onupdateinvestigation': '\n  subscription OnUpdateInvestigation {\n    onUpdateInvestigation {\n      id\n      title\n      from\n      createdAt\n      currentState\n      HumanID\n      currentStateID\n      severity\n      priority\n      location\n      labels {\n        nextToken\n      }\n      channelId\n      investigationChannel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      updatedAt\n      resolvedTime\n      resolvedComment\n      Symptoms\n      MMNodeLinks {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n      meetingType\n      meetingId\n    }\n  }\n',
 'onupdateinvestigationevent': '\n  subscription OnUpdateInvestigationEvent {\n    onUpdateInvestigationEvent {\n      id\n      createdAt\n      updatedAt\n      author\n      content\n      type\n      links\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdateinvestigationguestuserlink': '\n  subscription OnUpdateInvestigationGuestUserLink {\n    onUpdateInvestigationGuestUserLink {\n      id\n      userName\n      createdAt\n      updatedAt\n      investigationID\n      channelID\n    }\n  }\n',
 'onupdatelabel': '\n  subscription OnUpdateLabel {\n    onUpdateLabel {\n      id\n      name\n      color\n      type\n      investigations {\n        nextToken\n      }\n      userSettings {\n        nextToken\n      }\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdateleadboard': '\n  subscription OnUpdateLeadBoard {\n    onUpdateLeadBoard {\n      id\n      investigationId\n      content\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdateleadboardnode': '\n  subscription OnUpdateLeadBoardNode {\n    onUpdateLeadBoardNode {\n      id\n      localID\n      createdAt\n      updatedAt\n      author\n      content\n      title\n      notes\n      associatedPlaybooks\n      associatedCommands\n      InvestLinks {\n        nextToken\n      }\n    }\n  }\n',
 'onupdatemessage': '\n  subscription OnUpdateMessage {\n    onUpdateMessage {\n      id\n      authorId\n      content\n      type\n      channel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      messageChannelId\n      createdAt\n      updatedAt\n      author {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'onupdatemmnodelink': '\n  subscription OnUpdateMmNodeLink {\n    onUpdateMMNodeLink {\n      id\n      createdAt\n      updatedAt\n      assigned\n      state\n      content\n      author\n      investigationID\n      connectionToTask\n      LBNID\n      LeadBoardNodeId {\n        id\n        localID\n        createdAt\n        updatedAt\n        author\n        content\n        title\n        notes\n        associatedPlaybooks\n        associatedCommands\n      }\n      investigationId {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdatenotification': '\n  subscription OnUpdateNotification {\n    onUpdateNotification {\n      id\n      userName\n      content\n      containerType\n      containerId\n      investigationId\n      isViewed\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdatepin': '\n  subscription OnUpdatePin {\n    onUpdatePin {\n      id\n      imageId\n      content\n      createdAt\n      updatedAt\n      author\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdateprivatekey': '\n  subscription OnUpdatePrivateKey {\n    onUpdatePrivateKey {\n      id\n      sshKey\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdateremotecontrol': '\n  subscription OnUpdateRemoteControl {\n    onUpdateRemoteControl {\n      id\n      from\n      to\n      command\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdatereportsummaryeditor': '\n  subscription OnUpdateReportSummaryEditor {\n    onUpdateReportSummaryEditor {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      author\n      content\n      type\n    }\n  }\n',
 'onupdaterunbookconnectorformlink': '\n  subscription OnUpdateRunbookConnectorFormLink {\n    onUpdateRunbookConnectorFormLink {\n      id\n      connectorFormId\n      runbookId\n      connectorForm {\n        id\n        createdAt\n        updatedAt\n        name\n        owner\n        connectorID\n        configData\n        commandData\n        nodeData\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n      createdAt\n      updatedAt\n      runbook {\n        id\n        name\n        description\n        content\n        author\n        commands\n        createdAt\n        updatedAt\n        RunBookConnectors\n        type\n        longSave\n        rbVars\n        scope\n        PeopleCanView\n        PeopleCanAccess\n        GroupsCanView\n        GroupsCanAccess\n      }\n    }\n  }\n',
 'onupdateschedpbs': '\n  subscription OnUpdateSchedPBs {\n    onUpdateSchedPBs {\n      id\n      pbId\n      frequency\n      pbName\n      rbVars\n      scheduled\n      createdAt\n      updatedAt\n      author\n    }\n  }\n',
 'onupdatesshtabs': '\n  subscription OnUpdateSshTabs {\n    onUpdateSshTabs {\n      id\n      investigationId\n      host\n      author\n      userName\n      createdAt\n      updatedAt\n    }\n  }\n',
 'onupdatestash': '\n  subscription OnUpdateStash {\n    onUpdateStash {\n      id\n      Key\n      Value\n      createdAt\n      updatedAt\n      author\n      scope\n      PeopleCanView\n      PeopleCanAccess\n      GroupsCanView\n      GroupsCanAccess\n    }\n  }\n',
 'onupdatestate': '\n  subscription OnUpdateState {\n    onUpdateState {\n      id\n      name\n      createdAt\n      updatedAt\n      author\n      lastState\n      investigationId\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdatesummaryinvestigation': '\n  subscription OnUpdateSummaryInvestigation($owner: String) {\n    onUpdateSummaryInvestigation(owner: $owner) {\n      id\n      createdAt\n      updatedAt\n      resolvedTime\n      OriginalID\n      title\n      HumanID\n      Commands\n      InvestigationEvents\n      CompleteInvestigationEvents\n      Participants\n      Comments\n      Pins\n      AvailableRunbooks\n      UsedRunbooks\n      Hints\n      Symptoms\n      owner\n    }\n  }\n',
 'onupdatetenantcustomer': '\n  subscription OnUpdateTenantCustomer {\n    onUpdateTenantCustomer {\n      label\n      impactLabels\n      createdAt\n      updatedAt\n      customerName\n      email\n      phoneno\n      SLAType\n      city\n      state\n      contry\n      zipcode\n    }\n  }\n',
 'onupdatetranscriptionrecords': '\n  subscription OnUpdateTranscriptionRecords {\n    onUpdateTranscriptionRecords {\n      id\n      investigationId\n      createdAt\n      updatedAt\n      spokenBy\n      content\n    }\n  }\n',
 'onupdateusedtogenhintalready': '\n  subscription OnUpdateUsedToGenHintAlready {\n    onUpdateUsedToGenHintAlready {\n      id\n      createdAt\n      updatedAt\n      investigationId\n      commands\n      text\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n    }\n  }\n',
 'onupdateuser': '\n  subscription OnUpdateUser($owner: String) {\n    onUpdateUser(owner: $owner) {\n      id\n      username\n      email\n      firstname\n      lastname\n      avatar\n      mood\n      name\n      role\n      status\n      timezone\n      phone\n      address\n      location\n      chatList {\n        nextToken\n      }\n      messages {\n        nextToken\n      }\n      createdAt\n      updatedAt\n      owner\n    }\n  }\n',
 'onupdateuseractivity': '\n  subscription OnUpdateUserActivity {\n    onUpdateUserActivity {\n      id\n      userID\n      status\n      investigationID\n      createdAt\n      updatedAt\n      investigation {\n        id\n        title\n        from\n        createdAt\n        currentState\n        HumanID\n        currentStateID\n        severity\n        priority\n        location\n        channelId\n        updatedAt\n        resolvedTime\n        resolvedComment\n        Symptoms\n        meetingType\n        meetingId\n      }\n      user {\n        id\n        username\n        email\n        firstname\n        lastname\n        avatar\n        mood\n        name\n        role\n        status\n        timezone\n        phone\n        address\n        location\n        createdAt\n        updatedAt\n        owner\n      }\n    }\n  }\n',
 'onupdateusersettinglabellink': '\n  subscription OnUpdateUserSettingLabelLink {\n    onUpdateUserSettingLabelLink {\n      id\n      userSettingId\n      userSetting {\n        id\n        userId\n        owner\n        createdAt\n        updatedAt\n        value\n        url\n        name\n        type\n        showWelcomeNext\n        showWelcomeSkip\n        showWelcomeRemind\n        welcomeData\n      }\n      labelID\n      label {\n        id\n        name\n        color\n        type\n        createdAt\n        updatedAt\n      }\n      type\n      createdAt\n      updatedAt\n    }\n  }\n',
 'subscribetooneinvestigation': '\n  subscription SubscribeToOneInvestigation($id: ID) {\n    subscribeToOneInvestigation(id: $id) {\n      id\n      title\n      from\n      createdAt\n      currentState\n      HumanID\n      currentStateID\n      severity\n      priority\n      location\n      labels {\n        nextToken\n      }\n      channelId\n      investigationChannel {\n        id\n        name\n        title\n        members\n        membersState\n        createdAt\n        updatedAt\n        memberLocation\n      }\n      updatedAt\n      resolvedTime\n      resolvedComment\n      Symptoms\n      MMNodeLinks {\n        nextToken\n      }\n      CheckListInvLink {\n        nextToken\n      }\n      meetingType\n      meetingId\n    }\n  }\n'}
